summaryrefslogtreecommitdiffstats
path: root/src/calltreedlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/calltreedlg.h')
-rw-r--r--src/calltreedlg.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/calltreedlg.h b/src/calltreedlg.h
index d5f567b..092fd7d 100644
--- a/src/calltreedlg.h
+++ b/src/calltreedlg.h
@@ -28,8 +28,8 @@
#ifndef CALLTREEDLG_H
#define CALLTREEDLG_H
-#include <qwidget.h>
-#include <qlistview.h>
+#include <ntqwidget.h>
+#include <ntqlistview.h>
#include <calltreelayout.h>
/**
@@ -38,7 +38,7 @@
* - Call graph, showing both calling and call functions
* - Called functions tree
* - Calling functions tree
* NOTE: This is class is now derived from QWidget instead of QDialog. This
* means that call-trees are independent windows, which can be maximised or
* minimised.
* @author Elad Lahav
@@ -48,15 +48,15 @@ class CallTreeDlg : public CallTreeLayout
Q_OBJECT
public:
- CallTreeDlg(QWidget* pParent = 0, const char* szName = 0);
+ CallTreeDlg(TQWidget* pParent = 0, const char* szName = 0);
~CallTreeDlg();
- void setRoot(const QString&);
- bool load(const QString&, const QString&);
- void store(const QString&);
+ void setRoot(const TQString&);
+ bool load(const TQString&, const TQString&);
+ void store(const TQString&);
/** Returns Call Tree filename */
- QString getFileName() { return m_sFileName; }
+ TQString getFileName() { return m_sFileName; }
public slots:
virtual void show();
@@ -70,7 +70,7 @@ signals:
* @param sPath The full path of the file to show
* @param nLine The line number in this file
*/
- void lineRequested(const QString& sPath, uint nLine);
+ void lineRequested(const TQString& sPath, uint nLine);
/**
* Emitted when the user closes the tree view.
@@ -78,7 +78,7 @@ signals:
void closed(const CallTreeDlg*);
protected:
- virtual void closeEvent(QCloseEvent*);
+ virtual void closeEvent(TQCloseEvent*);
protected slots:
virtual void slotSaveClicked();
@@ -90,16 +90,16 @@ protected slots:
private:
/** The root function. */
- QString m_sRoot;
+ TQString m_sRoot;
/** A unique file name used for storing the call tree on a file.
The name is a combination of the root function and an incremented
index. */
- QString m_sFileName;
+ TQString m_sFileName;
/** The full path of the file on which the call tree was saved
(empty if this graph was never stored). */
- QString m_sFilePath;
+ TQString m_sFilePath;
/** The view to show when the dialogue is first displayed. */
int m_nDefView;
@@ -38,7 +38,7 @@
* - Called functions tree
* - Calling functions tree
- * NOTE: This is class is now derived from QWidget instead of QDialog. This
+ * NOTE: This is class is now derived from TQWidget instead of TQDialog. This
* means that call-trees are independent windows, which can be maximised or
* minimised.